跳到主要内容

Tls13ClientSessionValue

结构体 Tls13ClientSessionValue 

pub struct Tls13ClientSessionValue { /* private fields */ }

实现

Source

impl Tls13ClientSessionValue

pub fn max_early_data_size(&self) -> u32

pub fn suite(&self) -> &'static Tls13CipherSuite

pub fn set_quic_params(&mut self, quic_params: &[u8])

pub fn quic_params(&self) -> Vec<u8>

Trait 实现

Source

impl Debug for Tls13ClientSessionValue

Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化此值。 更多信息
Source

impl Deref for Tls13ClientSessionValue

Source

type Target = ClientSessionCommon

解引用后得到的类型。
Source

fn deref(&self) -> &Self::Target

解引用此值。

自动 Trait 实现

Blanket 实现

Source

impl<T> Any for T
where T: 'static + ?Sized,

Source

fn type_id(&self) -> TypeId

Gets the TypeId of self. 更多信息
Source

impl<T> Borrow<T> for T
where T: ?Sized,

Source

fn borrow(&self) -> &T

Immutably borrows 从 an owned value. 更多信息
Source

impl<T> BorrowMut<T> for T
where T: ?Sized,

Source

fn borrow_mut(&mut self) -> &mut T

Mutably borrows 从 an owned value. 更多信息
Source

impl<T> From<T> for T

Source

fn from(t: T) -> T

原样返回传入的参数。

Source

impl<T, U> Into<U> for T
where U: From<T>,

Source

fn into(self) -> U

Calls U::从(self)

That is, this conversion is whatever the implementation of From<T> 用于 U 的实现方式。

Source

impl<P, T> Receiver for P
where P: Deref<Target = T> + ?Sized, T: ?Sized,

Source

type Target = T

🔬This is a nightly-only experimental API. (arbitrary_self_types)
此 target type on which the method may be called.
Source

impl<T, U> TryFrom<U> for T
where U: Into<T>,

Source

type Error = Infallible

转换出错时返回的类型。
Source

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行转换。
Source

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

Source

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
Source

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行转换。