跳到主要内容

UnbufferedClientConnection

结构体 UnbufferedClientConnection 

pub struct UnbufferedClientConnection { /* private fields */ }
展开描述

ClientConnection 的非缓冲版本

,请参见 crate::unbuffered module docs 用于 more details

实现

Source

impl UnbufferedClientConnection

pub fn new( config: Arc<ClientConfig>, name: ServerName<'static>, ) -> Result<Self, Error>

创建一个新的 ClientConnection config controls how we behave in the TLS protocol, name is the name of the server we want 到 talk 到.

pub fn new_with_alpn( config: Arc<ClientConfig>, name: ServerName<'static>, alpn_protocols: Vec<Vec<u8>>, ) -> Result<Self, Error>

创建一个新的 UnbufferedClientConnection with custom ALPN protocols.

pub fn dangerous_extract_secrets(self) -> Result<ExtractedSecrets, Error>

👎Deprecated: dangerous_extract_secrets() does not support session tickets or key updates, use dangerous_into_kernel_connection() instead

提取密钥,以便在配置 kTLS 时使用,例如。 Should be 用 with care as it exposes secret 密钥材料。

pub fn dangerous_into_kernel_connection( self, ) -> Result<(ExtractedSecrets, KernelConnection<ClientConnectionData>), Error>

Extract secrets 并 一个 KernelConnection object.

This allows you use rustls 到 manage keys 并 then manage encryption 并 decryption yourself (e.g. 用于 kTLS)。

Should be 用 with care as it exposes secret 密钥材料。

,请参见 crate::kernel documentations 用于 details on prerequisites 用于 calling this method.

pub fn tls13_tickets_received(&self) -> u32

返回数量 TLS 1.3 已接收的票据

Methods from Deref<Target = UnbufferedConnectionCommon<ClientConnectionData>>

pub fn process_tls_records<'c, 'i>( &'c mut self, incoming_tls: &'i mut [u8], ) -> UnbufferedStatus<'c, 'i, ClientConnectionData>

Processes TLS 记录 in incoming_tls 缓冲区 until 新 UnbufferedStatus is reached.

Methods from Deref<Target = CommonState>

pub fn wants_write(&self) -> bool

如果调用者应尽快调用以下方法,则返回 true: Connection::write_tls 尽快。

pub fn is_handshaking(&self) -> bool

如果连接当前正在执行 TLS 握手,则返回 true。

During this time 明文 written 到 the connection is buffered in memory. After Connection::process_new_packets() has been called, this might start 到 return false while the final handshake packets still need 到 be extracted 从 the connection’s buffers.

pub fn peer_certificates(&self) -> Option<&[CertificateDer<'static>]>

检索对等方用于身份验证的证书链或原始公钥。

此 order of 证书 chain is as it appears in the TLS protocol: the first certificate relates 到 the peer, the second certifies the first, the third certifies the second, 并 so on.

When using raw public keys, the first 并 only element 是 raw 公钥.

This is made available 用于 both full 并 resumed handshakes.

For clients, this 是 certificate chain 或 the raw 公钥 of the server.

For servers, this 是 certificate chain 或 the raw 公钥 of the client, if client authentication was completed.

此 return value is None until this value is available.

Note: the return type of the ‘certificate’, when using raw public keys is CertificateDer<'static> even though this should technically be 一个 SubjectPublicKeyInfoDer<'static>。 This choice simplifies the API 并 ensures backwards compatibility.

pub fn alpn_protocol(&self) -> Option<&[u8]>

检索通过 ALPN 与对等方协商的协议。

A return value of None after handshake completion means no protocol was agreed (because no protocols were offered 或 已接受 by the peer)。

pub fn negotiated_cipher_suite(&self) -> Option<SupportedCipherSuite>

检索与对等方协商的密码套件。

在密码套件协商一致之前返回 None。

pub fn negotiated_key_exchange_group( &self, ) -> Option<&'static dyn SupportedKxGroup>

检索与对等方协商的密钥交换组。

This function may return None depending on the state of the connection, the type of handshake, 并 the protocol version.

If CommonState::is_handshaking() 为 true,此函数将返回 None。 Similarly, if the CommonState::handshake_kind() is HandshakeKind::Resumed 并 the CommonState::protocol_version() is TLS 1.2, then no key exchange will have occurred 并 此函数将返回 None

pub fn protocol_version(&self) -> Option<ProtocolVersion>

检索与对等方协商的协议版本。

This returns None until the version is agreed.

pub fn handshake_kind(&self) -> Option<HandshakeKind>

执行的握手类型。

它会告知握手是否为恢复握手。

This 将返回 None before it is known which sort of handshake occurred.

pub fn wants_read(&self) -> bool

如果调用者应尽快调用以下方法,则返回 true: Connection::read_tls as soon as possible.

如果有要读取的待处理明文数据,请使用 Connection::reader, this returns false. If your application respects this mechanism, only one full TLS message , buffered by rustls.

Trait 实现

Source

impl Deref for UnbufferedClientConnection

Source

type Target = UnbufferedConnectionCommon<ClientConnectionData>

解引用后得到的类型。
Source

fn deref(&self) -> &Self::Target

解引用此值。
Source

impl DerefMut for UnbufferedClientConnection

Source

fn deref_mut(&mut self) -> &mut Self::Target

以可变方式解引用此值。

自动 Trait 实现

Blanket 实现

Source

impl<T> Any for T
where T: 'static + ?Sized,

Source

fn type_id(&self) -> TypeId

Gets the TypeId of self. 更多信息
Source

impl<T> Borrow<T> for T
where T: ?Sized,

Source

fn borrow(&self) -> &T

Immutably borrows 从 an owned value. 更多信息
Source

impl<T> BorrowMut<T> for T
where T: ?Sized,

Source

fn borrow_mut(&mut self) -> &mut T

Mutably borrows 从 an owned value. 更多信息
Source

impl<T> From<T> for T

Source

fn from(t: T) -> T

原样返回传入的参数。

Source

impl<T, U> Into<U> for T
where U: From<T>,

Source

fn into(self) -> U

Calls U::从(self)

That is, this conversion is whatever the implementation of From<T> 用于 U 的实现方式。

Source

impl<P, T> Receiver for P
where P: Deref<Target = T> + ?Sized, T: ?Sized,

Source

type Target = T

🔬This is a nightly-only experimental API. (arbitrary_self_types)
此 target type on which the method may be called.
Source

impl<T, U> TryFrom<U> for T
where U: Into<T>,

Source

type Error = Infallible

转换出错时返回的类型。
Source

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行转换。
Source

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

Source

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
Source

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行转换。