pub struct WriteEarlyData<'a> { /* private fields */ }展开描述
Stub that implements io::Write 并 dispatches 到 write_early_data。
实现
Sourceimpl<'a> WriteEarlyData<'a>
impl<'a> WriteEarlyData<'a>
Sourcepub fn bytes_left(&self) -> usize
pub fn bytes_left(&self) -> usize
可发送的字节数量 once this reaches zero.
Trait 实现
Sourceimpl Write for WriteEarlyData<'_>
impl Write for WriteEarlyData<'_>
Sourcefn write(&mut self, buf: &[u8]) -> Result<usize>
fn write(&mut self, buf: &[u8]) -> Result<usize>
Writes 缓冲区 into this writer, returning how many bytes were written. 更多信息
Sourcefn flush(&mut self) -> Result<()>
fn flush(&mut self) -> Result<()>
Flushes this output stream, ensuring that all intermediately buffered
contents reach their destination. 更多信息
Sourcefn is_write_vectored(&self) -> bool
fn is_write_vectored(&self) -> bool
🔬This is a nightly-only experimental API. (
can_vector)1.0.0 · Sourcefn write_all(&mut self, buf: &[u8]) -> Result<(), Error>
fn write_all(&mut self, buf: &[u8]) -> Result<(), Error>
Attempts 到 write an entire 缓冲区 into this writer. 更多信息
Sourcefn write_all_vectored(&mut self, bufs: &mut [IoSlice<'_>]) -> Result<(), Error>
fn write_all_vectored(&mut self, bufs: &mut [IoSlice<'_>]) -> Result<(), Error>
🔬This is a nightly-only experimental API. (
write_all_vectored)Attempts 到 write multiple buffers into this writer. 更多信息
自动 Trait 实现
impl<'a> Freeze for WriteEarlyData<'a>
impl<'a> !RefUnwindSafe for WriteEarlyData<'a>
impl<'a> Send for WriteEarlyData<'a>
impl<'a> Sync for WriteEarlyData<'a>
impl<'a> Unpin for WriteEarlyData<'a>
impl<'a> UnsafeUnpin for WriteEarlyData<'a>
impl<'a> !UnwindSafe for WriteEarlyData<'a>
Blanket 实现
Sourceimpl<T> BorrowMut<T> for Twhere
T: ?Sized,
impl<T> BorrowMut<T> for Twhere
T: ?Sized,
Sourcefn borrow_mut(&mut self) -> &mut T
fn borrow_mut(&mut self) -> &mut T
Mutably borrows 从 an owned value. 更多信息